@@ -10,13 +10,10 @@ def Fibonacci(limit):
      """ Printing the first 2 entries of the Fibonacci Series """
      print(a)
      print(b)
-     while(count < limit - 1):
-         """ Printing the rest of the Fibonacci Series """
+     """ Printing the rest of the Fibonacci Series - rewritten with for loop instead of while """
+     for num in range(limit):
          c = a + b
          print(c)
          a = b
          b = c
-         count+=1
 
- 
-    
